@@ -396,7 +396,8 @@ def profit_plot(df, rvar, lev, pred, qnt=10, cost=1, margin=2):
         for p in pred
     ]
     df = pd.concat(df)
-
+    fig = sns.lineplot(x="cum_prop", y="cum_profit", data=df, hue=group, marker="o")
+    fig.set(ylabel="Profit", xlabel="Proportion of customers")
     fig.axhline(1, linestyle="--", linewidth=1)
     [fig.axvline(l, linestyle="--", linewidth=1) for l in cnf]
     return fig
